@@ -518,6 +518,9 @@ class EndpointsPrismaCloudAPIMixin():
             next_page_token = api_response.pop('nextPageToken', None)
         return result
 
+    def search_suggest_list_read(self, query_to_suggest):
+        return self.execute('POST', 'search/suggest', body_params=query_to_suggest)
+
     """
     Configuration
 
